Download

Struct Download 

pub struct Download {
    pub url: Url,
    pub filename: String,
}
Represents a file to be downloaded.

Fields

url: Url

URL of the file to download.

filename: String

File name used to save the file on disk.

Implementations

Source

impl Download

pub fn new(url: &Url, filename: &str) -> Self

Creates a new Download.

When using the Download::try_from method, the file name is automatically extracted from the URL.

Example

The following calls are equivalent, minus some extra URL validations performed by try_from:

use trauma::download::Download;
use reqwest::Url;

Download::try_from("https://example.com/file-0.1.2.zip")?;
Download::new(&Url::parse("https://example.com/file-0.1.2.zip")?, "file-0.1.2.zip");
pub async fn is_resumable( &self, client: &ClientWithMiddleware, ) -> Result<bool, Error>

Check whether the download is resumable.

pub async fn content_length( &self, client: &ClientWithMiddleware, ) -> Result<Option<u64>, Error>

Retrieve the content_length of the download.

Returns None if the “content-length” header is missing or if its value is not a u64.